# GW Low-latency Test Suite

## Features

The gw-lts software provides:

* real-time end-to-end consistency checks of science outputs from gravitational wave searches
* capability to simulate gravitational wave search outputs with a fake data set
* ability to display results with an example Grafana dashboard template

## Installation

### virtual environment
```python3
python3 -m venv <env name>
source <env name>/bin/activate
pip install --update pip
pip install gw-lts
```

## Usage

See: https://git.ligo.org/rebecca.ewing/test-suite#quickstart

